pub enum BanValidationError {
MemberNotFound(MemberId),
BannerNotFound(MemberId),
NotInInviteChain(MemberId, MemberId),
SelfInvitationDetected(MemberId),
InviterNotFound(MemberId),
ExceededMaximumBans,
}Expand description
Represents different types of validation errors that can occur with bans
Variants
MemberNotFound(MemberId)
The banned member was not found in the member list
BannerNotFound(MemberId)
The banning member was not found in the member list
NotInInviteChain(MemberId, MemberId)
The banning member is not in the invite chain of the banned member
SelfInvitationDetected(MemberId)
A circular invite chain was detected
InviterNotFound(MemberId)
The inviting member was not found for a member in the chain
ExceededMaximumBans
The number of bans exceeds the maximum allowed