pub struct StateVersion(pub u32);Expand description
Wrapper for state version that implements ComposableState.
The version is metadata about the state format, not user content. It doesn’t change via deltas - it’s set when the state is created and verified to be compatible when loaded.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for StateVersion
impl Clone for StateVersion
Sourcefn clone(&self) -> StateVersion
fn clone(&self) -> StateVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposableState for StateVersion
impl ComposableState for StateVersion
type ParentState = ChatRoomStateV1
type Summary = u32
type Delta = ()
type Parameters = ChatRoomParametersV1
fn verify( &self, _parent_state: &Self::ParentState, _parameters: &Self::Parameters, ) -> Result<(), String>
fn summarize( &self, _parent_state: &Self::ParentState, _parameters: &Self::Parameters, ) -> Self::Summary
fn delta( &self, _parent_state: &Self::ParentState, _parameters: &Self::Parameters, _old_state_summary: &Self::Summary, ) -> Option<Self::Delta>
Sourcefn apply_delta(
&mut self,
_parent_state: &Self::ParentState,
_parameters: &Self::Parameters,
_delta: &Option<Self::Delta>,
) -> Result<(), String>
fn apply_delta( &mut self, _parent_state: &Self::ParentState, _parameters: &Self::Parameters, _delta: &Option<Self::Delta>, ) -> Result<(), String>
Applies the specified
delta to the current state. Read moreSourcefn merge(
&mut self,
parent_state: &Self::ParentState,
parameters: &Self::Parameters,
other_state: &Self,
) -> Result<(), String>
fn merge( &mut self, parent_state: &Self::ParentState, parameters: &Self::Parameters, other_state: &Self, ) -> Result<(), String>
Merges the current state with another state.
Sourceimpl Debug for StateVersion
impl Debug for StateVersion
Sourceimpl Default for StateVersion
impl Default for StateVersion
Sourcefn default() -> StateVersion
fn default() -> StateVersion
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StateVersion
impl<'de> Deserialize<'de> for StateVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StateVersion
impl PartialEq for StateVersion
Sourceimpl Serialize for StateVersion
impl Serialize for StateVersion
impl StructuralPartialEq for StateVersion