Module chat_delegate

Module chat_delegate 

Structs

ChatDelegateKey

Enums

ChatDelegateRequestMsg
Messages sent from the App to the Chat Delegate
ChatDelegateResponseMsg
Responses sent from the Chat Delegate to the App

Type Aliases

RequestId
Unique identifier for a signing request (for request/response correlation)
RoomKey
Room key identifier (owner’s verifying key bytes)