ChatDelegateRequestMsg

Enum ChatDelegateRequestMsg 

pub enum ChatDelegateRequestMsg {
Show 14 variants StoreRequest { key: ChatDelegateKey, value: Vec<u8>, }, GetRequest { key: ChatDelegateKey, }, DeleteRequest { key: ChatDelegateKey, }, ListRequest, StoreSigningKey { room_key: RoomKey, signing_key_bytes: [u8; 32], }, GetPublicKey { room_key: RoomKey, }, SignMessage { room_key: RoomKey, request_id: RequestId, message_bytes: Vec<u8>, }, SignMember { room_key: RoomKey, request_id: RequestId, member_bytes: Vec<u8>, }, SignBan { room_key: RoomKey, request_id: RequestId, ban_bytes: Vec<u8>, }, SignConfig { room_key: RoomKey, request_id: RequestId, config_bytes: Vec<u8>, }, SignMemberInfo { room_key: RoomKey, request_id: RequestId, member_info_bytes: Vec<u8>, }, SignSecretVersion { room_key: RoomKey, request_id: RequestId, record_bytes: Vec<u8>, }, SignEncryptedSecret { room_key: RoomKey, request_id: RequestId, secret_bytes: Vec<u8>, }, SignUpgrade { room_key: RoomKey, request_id: RequestId, upgrade_bytes: Vec<u8>, },
}
Messages sent from the App to the Chat Delegate

Variants



StoreRequest

Fields

value: Vec<u8>


GetRequest



DeleteRequest



ListRequest



StoreSigningKey

Store a signing key for a room (room_key = owner’s verifying key bytes)

Fields

room_key: RoomKey
signing_key_bytes: [u8; 32]


GetPublicKey

Get the public key for a stored signing key

Fields

room_key: RoomKey


SignMessage

Sign a message (MessageV1 serialized)

Fields

room_key: RoomKey
request_id: RequestId
message_bytes: Vec<u8>


SignMember

Sign a member invitation (Member serialized)

Fields

room_key: RoomKey
request_id: RequestId
member_bytes: Vec<u8>


SignBan

Sign a ban (BanV1 serialized)

Fields

room_key: RoomKey
request_id: RequestId
ban_bytes: Vec<u8>


SignConfig

Sign a room configuration (Configuration serialized)

Fields

room_key: RoomKey
request_id: RequestId
config_bytes: Vec<u8>


SignMemberInfo

Sign member info (MemberInfo serialized)

Fields

room_key: RoomKey
request_id: RequestId
member_info_bytes: Vec<u8>


SignSecretVersion

Sign a secret version record (SecretVersionRecordV1 serialized)

Fields

room_key: RoomKey
request_id: RequestId
record_bytes: Vec<u8>


SignEncryptedSecret

Sign an encrypted secret for member (EncryptedSecretForMemberV1 serialized)

Fields

room_key: RoomKey
request_id: RequestId
secret_bytes: Vec<u8>


SignUpgrade

Sign a room upgrade (RoomUpgrade serialized)

Fields

room_key: RoomKey
request_id: RequestId
upgrade_bytes: Vec<u8>