pub enum RoomMessageBody {
Public {
plaintext: String,
},
Private {
ciphertext: Vec<u8>,
nonce: [u8; 12],
secret_version: SecretVersion,
},
}Expand description
Message body that can be either public plaintext or private encrypted
Variants
Implementations
Sourceimpl RoomMessageBody
impl RoomMessageBody
Sourcepub fn private(
ciphertext: Vec<u8>,
nonce: [u8; 12],
secret_version: SecretVersion,
) -> Self
pub fn private( ciphertext: Vec<u8>, nonce: [u8; 12], secret_version: SecretVersion, ) -> Self
Create a new private message
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Check if this is a private message
Sourcepub fn content_len(&self) -> usize
pub fn content_len(&self) -> usize
Get the content length for validation
Sourcepub fn secret_version(&self) -> Option<SecretVersion>
pub fn secret_version(&self) -> Option<SecretVersion>
Get the secret version (if private)
Sourcepub fn to_string_lossy(&self) -> String
pub fn to_string_lossy(&self) -> String
Get a string representation for display purposes This is a temporary helper for UI integration during development
Sourcepub fn as_public_string(&self) -> Option<&str>
pub fn as_public_string(&self) -> Option<&str>
Try to get the public plaintext, returns None if private